@@ -13,6 +13,20 @@ pub trait DrawDestination {
     fn draw_canvas(&mut self, canvas: &Canvas, source: Rect, destination: Rect);
 }
 
+impl<D: DrawDestination + ?Sized> DrawDestination for &mut D {
+    fn draw_rectangle(&mut self, rectangle: Rect, color: Rgba) {
+        (**self).draw_rectangle(rectangle, color);
+    }
+
+    fn draw_texture(&mut self, texture: &Texture, source: Rect, destination: Rect) {
+        (**self).draw_texture(texture, source, destination);
+    }
+
+    fn draw_canvas(&mut self, canvas: &Canvas, source: Rect, destination: Rect) {
+        (**self).draw_canvas(canvas, source, destination);
+    }
+}
+
 #[derive(Debug)]
 pub struct Canvas {
     pub(crate) id: u32,
